@@ -1,5 +1,4 @@
-"""The `servo.logging` module provides standard logging capabilities to the
-servo package and its dependencies.
+"""The `servo.logging` module provides logging capabilities to the servo package and its dependencies.
 
 Logging is implemented on top of the
 [loguru](https://loguru.readthedocs.io/en/stable/) library.
@@ -17,8 +16,10 @@ from typing import Any, Awaitable, Callable, Dict, Optional, Union
 
 import loguru
 
+import servo.assembly
 import servo.events
 
+
 __all__ = (
     "Mixin",
     "Filter",
@@ -35,34 +36,38 @@ logger = loguru.logger
 
 
 class Mixin:
-    """The `servo.logging.Mixin` class is a convenience class for adding
+    """Provides a convenience interface for accessing the logger as a property.
+
+    The `servo.logging.Mixin` class is a convenience class for adding
     logging capabilities to arbitrary classes through multiple inheritance.
     """
 
     @property
     def logger(self) -> loguru.Logger:
-        """Returns the servo package logger"""
+        """Return the servo package logger."""
         global logger
         return logger
 
 
 class Filter:
-    """
+    """The level of messages that are to be outputted via logging.
+
     NOTE: The level on the sink needs to be set to 0.
     """
 
-    def __init__(self, level="INFO") -> None:
+    def __init__(self, level="INFO") -> None: # noqa: D107
         self.level = level
 
-    def __call__(self, record) -> bool:
+    def __call__(self, record) -> bool: # noqa: D102
         levelno = logger.level(self.level).no
         return record["level"].no >= levelno
 
 
 class ProgressHandler:
-    """
-    The ProgressHandler class provides transparent integration between logging events and
-    API based reporting to Opsani. Log messages annotated with a "progress" attribute are
+    """A logging handler that provides automatic progress reporting to the Opsani API.
+
+    The `ProgressHandler` class provides connectivity between logging events and API based
+    reporting to Opsani. Log messages annotated with a "progress" attribute are
     automatically picked up by the handler and reported back to the API via a callback.
 
     NOTE: We call the logger re-entrantly for misconfigured progress logging attempts. The
@@ -76,7 +81,7 @@ class ProgressHandler:
         exception_handler: Optional[
             Callable[[Exception], Union[None, Awaitable[None]]]
         ] = None,
-    ) -> None:
+    ) -> None: # noqa: D107
         self._progress_reporter = progress_reporter
         self._error_reporter = error_reporter
         self._exception_handler = exception_handler
@@ -84,7 +89,10 @@ class ProgressHandler:
         self._queue_processor = None
 
     async def sink(self, message: loguru.Message) -> None:
-        """An asynchronous loguru sink handling the progress reporting.
+        """Enqueue asynchronous tasks for reporting status of operations in progress.
+
+        An asynchronous loguru sink responsible for handling progress reporting.
+
         Implemented as a sink versus a `logging.Handler` because the Python stdlib logging package isn't async.
         """
         if self._queue_processor is None:
@@ -97,7 +105,7 @@ class ProgressHandler:
             return
 
         # Favor explicit connector in extra (see Mixin) else use the context var
-        connector = extra.get("connector", servo.events._connector_context_var.get())
+        connector = extra.get("connector", servo.current_connector())
         if not connector:
             return await self._report_error(
                 "declining request to report progress for record without a connector attribute",
@@ -106,7 +114,7 @@ class ProgressHandler:
 
         event_context: Optional[
             servo.events.EventContext
-        ] = servo.events._event_context_var.get()
+        ] = servo.current_event()
         operation = extra.get("operation", None)
         if not operation:
             if not event_context:
@@ -142,23 +150,31 @@ class ProgressHandler:
     async def shutdown(self) -> None:
         """Shutdown the progress handler by emptying the queue and releasing the queue processor."""
         await self._queue.join()
-        self._queue_processor.cancel()
-        await asyncio.gather(self._queue_processor, return_exceptions=True)
+
+        if self._queue_processor:
+            self._queue_processor.cancel()
+            await asyncio.gather(self._queue_processor, return_exceptions=True)
 
     async def _process_queue(self) -> None:
         while True:
             try:
                 progress = await self._queue.get()
                 if progress is None:
+                    logger.info(f"retrieved None from progress queue. halting progress reporting")
                     break
 
+                if int(progress['progress']) == 100:
+                    logger.debug(f"eliding 100% progress event: {progress}")
+                    continue
+
                 if asyncio.iscoroutinefunction(self._progress_reporter):
                     await self._progress_reporter(**progress)
                 else:
                     self._progress_reporter(**progress)
-            except asyncio.CancelledError:
+            except (asyncio.CancelledError, servo.errors.EventCancelledError):
                 pass  # Task cancellation should not be logged as an error.
             except Exception as error:  # pylint: disable=broad-except
+                logger.warning(f"encountered exception while processing progress logging: {repr(error)}")
                 if self._exception_handler:
                     if asyncio.iscoroutinefunction(self._exception_handler):
                         await self._exception_handler(error)
@@ -168,9 +184,7 @@ class ProgressHandler:
                 self._queue.task_done()
 
     async def _report_error(self, message: str, record) -> None:
-        """
-        Report an error message about rocessing a log message annotated with a `progress` attribute.
-        """
+        """Report an error message about processing a log message annotated with a `progress` attribute."""
         message = f"!!! WARNING: {record['name']}:{record['file'].name}:{record['line']} | servo.logging.ProgressHandler - {message}"
         if self._error_reporter:
             if asyncio.iscoroutinefunction(self._error_reporter):
@@ -180,7 +194,10 @@ class ProgressHandler:
 
 
 class InterceptHandler(logging.Handler):
-    def emit(self, record):
+    """A logging handler that forwards messages from Python stdlib logging to loguru."""
+
+    def emit(self, record) -> None:
+        """Emit a log record from Python stdlib logging facilities into loguru."""
         # Get corresponding Loguru level if it exists
         try:
             level = logger.level(record.levelname).name
@@ -207,10 +224,10 @@ DEFAULT_FORMAT = (
 
 
 class Formatter:
-    def __call__(self, record: dict) -> str:
-        """
-        Formats a log message with contextual information from the servo assembly.
-        """
+    """A logging formatter that is aware of assemblies, servos, and connectors."""
+
+    def __call__(self, record: dict) -> str: # noqa: D107
+        """Format a log message with contextual information about the servo assembly."""
         extra = record["extra"]
 
         # Add optional traceback
@@ -223,17 +240,22 @@ class Formatter:
         if not "component" in record["extra"]:
             # Favor explicit connector from the extra dict or use the context var
             if connector := extra.get(
-                "connector", servo.events._connector_context_var.get()
+                "connector", servo.current_connector()
             ):
                 component = connector.name
             else:
                 component = "servo"
 
             # Append event context if available
-            event_context = servo.events._event_context_var.get()
+            event_context = servo.current_event()
             if event_context:
                 component += f"[{event_context}]"
 
+            # If we are running multiservo, annotate that as well
+            assembly = servo.current_assembly()
+            if assembly and len(assembly.servos) > 1 and servo.current_servo():
+                component = f"{servo.current_servo().config.optimizer.id}({component})"
+
             extra["component"] = component
 
         return DEFAULT_FORMAT + "\n{exception}"
@@ -275,27 +297,23 @@ DEFAULT_HANDLERS = [
 
 
 def set_level(level: str) -> None:
-    """
-    Sets the logging threshold to the given level for all log handlers.
-    """
+    """Set the logging threshold to the given level for all log handlers."""
     DEFAULT_FILTER.level = level
 
 
 def set_colors(colors: bool) -> None:
-    """Sets whether ANSI colored output will be emitted to the logs.
+    """Set whether or not log messages should be outputted in ANSI color.
 
     Args:
-        colors (bool): Whether or not to color log output.
+        colors: Whether or not to color log output.
     """
     DEFAULT_STDERR_HANDLER["colorize"] = colors
     loguru.logger.remove()
     loguru.logger.configure(handlers=DEFAULT_HANDLERS)
 
 
-def reset_to_defaults() -> loguru.Logger:
-    """
-    Resets the logging subsystem to the default configuration and returns the logger instance.
-    """
+def reset_to_defaults() -> None:
+    """Reset the logging subsystem to the default configuration."""
     DEFAULT_FILTER.level = "INFO"
     DEFAULT_STDERR_HANDLER["colorize"] = None
 
@@ -305,12 +323,11 @@ def reset_to_defaults() -> loguru.Logger:
     # Intercept messages from backoff library
     logging.getLogger("backoff").addHandler(InterceptHandler())
 
-    return logger
-
 
 def friendly_decorator(f):
-    """
-    Returns a "decorator decorator" that wraps a decorator function such that it can be invoked
+    """Transform a decorated function into a decorator that can be called with or without parameters.
+
+    The returned function wraps a decorator function such that it can be invoked
     with or without parentheses such as:
 
         @decorator(with, arguments, and=kwargs)
@@ -332,9 +349,7 @@ def friendly_decorator(f):
 
 @friendly_decorator
 def log_execution(func, *, entry=True, exit=True, level="DEBUG"):
-    """
-    Log the execution of the decorated function.
-    """
+    """Log the execution of the decorated function."""
 
     @functools.wraps(func)
     def wrapped(*args, **kwargs):
@@ -352,9 +367,7 @@ def log_execution(func, *, entry=True, exit=True, level="DEBUG"):
 
 @friendly_decorator
 def log_execution_time(func, *, level="DEBUG"):
-    """
-    Log the execution time upon exit from the decorated function.
-    """
+    """Log the execution time upon exit from the decorated function."""
 
     @functools.wraps(func)
     def wrapped(*args, **kwargs):
@@ -375,4 +388,4 @@ def log_execution_time(func, *, level="DEBUG"):
 
 
 # Alias the loguru logger to hide implementation details
-logger = reset_to_defaults()
+reset_to_defaults()
